@@ -57,15 +57,21 @@ def set_status(data, status, user):
     Returns: Data
 
     """
-    if status == DataStatus.DELETED and (data.workspace is None or data.workspace.is_public is False):
-        raise exceptions.ModelError("the " + get_data_label() + " should be published if the targeted status is 'Deleted'")
+    if status == DataStatus.DELETED and (
+        data.workspace is None or data.workspace.is_public is False
+    ):
+        raise exceptions.ModelError(
+            "the "
+            + get_data_label()
+            + " should be published if the targeted status is 'Deleted'"
+        )
 
     # build the xsd tree
     xml_tree = XSDTree.build_tree(data.xml_content)
     # get the root
     root = xml_tree.getroot()
     # and change the attribute
-    root.attrib['status'] = status
+    root.attrib["status"] = status
     # update the xml content
     data.xml_content = XSDTree.tostring(xml_tree)
     # upsert the data
@@ -82,7 +88,7 @@ def get_status(data):
 
     """
     try:
-        return data.dict_content['Resource']['@status']
+        return data.dict_content["Resource"]["@status"]
     except Exception as e:
         raise exceptions.ModelError(str(e))
 
@@ -97,9 +103,14 @@ def generate_unique_local_id(length_id):
 
     """
     # we generate an local id
-    local_id = ''.join(random.choice(string.ascii_uppercase + string.digits) for _ in range(length_id))
+    local_id = "".join(
+        random.choice(string.ascii_uppercase + string.digits) for _ in range(length_id)
+    )
     # we make sure this local id does not exist in db
     while is_local_id_already_used(local_id):
         # otherwise we generate one until then
-        local_id = ''.join(random.choice(string.ascii_uppercase + string.digits) for _ in range(length_id))
+        local_id = "".join(
+            random.choice(string.ascii_uppercase + string.digits)
+            for _ in range(length_id)
+        )
     return local_id
